#!/bin/sh
## Test reduce subcommand to topologically reduce a repo
${REPOCUTTER:-repocutter} -q reduce <debranch.svn 

